@@ -16,7 +16,6 @@ import pickle
 import weakref
 import re
 import traceback
-import warnings
 from collections import deque
 
 RegexType = type(re.compile(""))
@@ -24,10 +23,9 @@ RegexType = type(re.compile(""))
 
 from twisted.python.compat import reraise, nativeString, NativeStringIO
 from twisted.python.compat import _PY3
-from twisted.python.deprecate import deprecated
 from twisted.python import compat
 from twisted.python.deprecate import _fullyQualifiedName as fullyQualifiedName
-from twisted.python.versions import Version
+from twisted.python._oldstyle import _oldStyle
 
 
 def prefixedMethodNames(classObj, prefix):
@@ -77,7 +75,7 @@ def addMethodNamesToDict(classObj, dict, prefix, baseClass=None):
         methods.  To collect all method names, do not pass a value for this
         parameter.
 
-    @return: C{None}
+    @return: L{None}
     """
     for base in classObj.__bases__:
         addMethodNamesToDict(base, dict, prefix, baseClass)
@@ -131,12 +129,19 @@ def accumulateMethods(obj, dict, prefix='', curClass=None):
         collecting methods.  Collection proceeds up.  To collect all methods
         from C{obj}, do not pass a value for this parameter.
 
-    @return: C{None}
+    @return: L{None}
     """
     if not curClass:
         curClass = obj.__class__
     for base in curClass.__bases__:
-        accumulateMethods(obj, dict, prefix, base)
+        # The implementation of the object class is different on PyPy vs.
+        # CPython.  This has the side effect of making accumulateMethods()
+        # pick up object methods from all new-style classes -
+        # such as __getattribute__, etc.
+        # If we ignore 'object' when accumulating methods, we can get
+        # consistent behavior on Pypy and CPython.
+        if base is not object:
+            accumulateMethods(obj, dict, prefix, base)
 
     for name, method in curClass.__dict__.items():
         optName = name[len(prefix):]
@@ -445,6 +450,8 @@ def safe_str(o):
         return _safeFormat(str, o)
 
 
+
+@_oldStyle
 class QueueMethod:
     """
     I represent a method that doesn't exist yet.
@@ -456,38 +463,6 @@ class QueueMethod:
         self.calls.append((self.name, args))
 
 
-def funcinfo(function):
-    """
-    this is more documentation for myself than useful code.
-    """
-    warnings.warn(
-        "[v2.5] Use inspect.getargspec instead of twisted.python.reflect.funcinfo",
-        DeprecationWarning,
-        stacklevel=2)
-    code=function.func_code
-    name=function.func_name
-    argc=code.co_argcount
-    argv=code.co_varnames[:argc]
-    defaults=function.func_defaults
-
-    out = []
-
-    out.append('The function %s accepts %s arguments' % (name ,argc))
-    if defaults:
-        required=argc-len(defaults)
-        out.append('It requires %s arguments' % required)
-        out.append('The arguments required are: %s' % argv[:required])
-        out.append('additional arguments are:')
-        for i in range(argc-required):
-            j=i+required
-            out.append('%s which has a default of' % (argv[j], defaults[i]))
-    return out
-
-
-ISNT=0
-WAS=1
-IS=2
-
 
 def fullFuncName(func):
     qualName = (str(pickle.whichmodule(func, func.__name__)) + '.' + func.__name__)
@@ -496,6 +471,7 @@ def fullFuncName(func):
     return qualName
 
 
+
 def getClass(obj):
     """
     Return the class or type of object 'obj'.
@@ -507,72 +483,6 @@ def getClass(obj):
         return type(obj)
 
 
-## the following were factored out of usage
-
-if not _PY3:
-    # The following functions aren't documented, nor tested, have much simpler
-    # builtin implementations and are not used within Twisted or "known"
-    # projects.
-
-    @deprecated(Version("Twisted", 14, 0, 0))
-    def getcurrent(clazz):
-        assert type(clazz) == types.ClassType, 'must be a class...'
-        module = namedModule(clazz.__module__)
-        currclass = getattr(module, clazz.__name__, None)
-        if currclass is None:
-            return clazz
-        return currclass
-
-
-    # Class graph nonsense
-    # I should really have a better name for this...
-    @deprecated(Version("Twisted", 14, 0, 0), "isinstance")
-    def isinst(inst,clazz):
-        if type(inst) != compat.InstanceType or type(clazz)!= types.ClassType:
-            return isinstance(inst,clazz)
-        cl = inst.__class__
-        cl2 = getcurrent(cl)
-        clazz = getcurrent(clazz)
-        if issubclass(cl2,clazz):
-            if cl == cl2:
-                return WAS
-            else:
-                inst.__class__ = cl2
-                return IS
-        else:
-            return ISNT
-
-
-    # These functions are still imported by libraries used in turn by the
-    # Twisted unit tests, like Nevow 0.10. Since they are deprecated,
-    # there's no need to port them to Python 3 (hence the condition above).
-    # https://bazaar.launchpad.net/~divmod-dev/divmod.org/trunk/revision/2716
-    # removed the dependency in Nevow. Once that is released, these functions
-    # can be safely removed from Twisted.
-
-    @deprecated(Version("Twisted", 11, 0, 0), "inspect.getmro")
-    def allYourBase(classObj, baseClass=None):
-        """
-        allYourBase(classObj, baseClass=None) -> list of all base
-        classes that are subclasses of baseClass, unless it is None,
-        in which case all bases will be added.
-        """
-        l = []
-        _accumulateBases(classObj, l, baseClass)
-        return l
-
-
-    @deprecated(Version("Twisted", 11, 0, 0), "inspect.getmro")
-    def accumulateBases(classObj, l, baseClass=None):
-        _accumulateBases(classObj, l, baseClass)
-
-
-    def _accumulateBases(classObj, l, baseClass=None):
-        for base in classObj.__bases__:
-            if baseClass is None or issubclass(base, baseClass):
-                l.append(base)
-            _accumulateBases(base, l, baseClass)
-
 
 def accumulateClassDict(classObj, attr, adict, baseClass=None):
     """
@@ -580,7 +490,7 @@ def accumulateClassDict(classObj, attr, adict, baseClass=None):
 
     Assuming all class attributes of this name are dictionaries.
     If any of the dictionaries being accumulated have the same key, the
-    one highest in the class heirarchy wins.
+    one highest in the class hierarchy wins.
     (XXX: If \"highest\" means \"closest to the starting class\".)
 
     Ex::
@@ -601,7 +511,7 @@ def accumulateClassDict(classObj, attr, adict, baseClass=None):
 
       accumulateClassDict(Lunch, \"properties\", dct)
 
-      print dct
+      print(dct)
 
     {\"taste\": \"bland\", \"colour\": \"green\", \"vegan\": 1}
     """
@@ -613,7 +523,7 @@ def accumulateClassDict(classObj, attr, adict, baseClass=None):
 
 def accumulateClassList(classObj, attr, listObj, baseClass=None):
     """
-    Accumulate all attributes of a given name in a class heirarchy into a single list.
+    Accumulate all attributes of a given name in a class hierarchy into a single list.
 
     Assuming all class attributes of this name are lists.
     """
@@ -709,15 +619,11 @@ if not _PY3:
 __all__ = [
     'InvalidName', 'ModuleNotFound', 'ObjectNotFound',
 
-    'ISNT', 'WAS', 'IS',
-
     'QueueMethod',
 
-    'funcinfo', 'fullFuncName', 'qual', 'getcurrent', 'getClass', 'isinst',
     'namedModule', 'namedObject', 'namedClass', 'namedAny', 'requireModule',
-    'safe_repr', 'safe_str', 'allYourBase', 'accumulateBases',
-    'prefixedMethodNames', 'addMethodNamesToDict', 'prefixedMethods',
-    'accumulateMethods',
+    'safe_repr', 'safe_str', 'prefixedMethodNames', 'addMethodNamesToDict',
+    'prefixedMethods', 'accumulateMethods', 'fullFuncName', 'qual', 'getClass',
     'accumulateClassDict', 'accumulateClassList', 'isSame', 'isLike',
     'modgrep', 'isOfType', 'findInstances', 'objgrep', 'filenameToModuleName',
     'fullyQualifiedName']
